@@ -31,5 +31,6 @@ impl<'a> Context<'a> {
 }
 
 fn random_u32() -> u32 {
-    rand::random()
+    let mut rng = nanorand::WyRand::new();
+    nanorand::Rng::generate(&mut rng)
 }
