@@ -8,8 +8,10 @@ use std::{env, path, process};
 mod color;
 mod config;
 mod context;
+mod file_paths;
 mod helper;
 mod interrupt;
+mod terminal;
 
 use context::Context;
 
@@ -33,6 +35,8 @@ enum ArgsAction {
     Repl,
     /// Evaluate the arguments.
     Eval(String),
+    /// Show the default config file
+    DefaultConfig,
 }
 
 fn print_spans(spans: Vec<fend_core::SpanRef<'_>>, config: &config::Config) -> String {
@@ -50,11 +54,6 @@ fn eval_and_print_res(
     int: &impl fend_core::Interrupt,
     config: &config::Config,
 ) -> EvalResult {
-    /*
-    let ms_since_1970 = chrono::Utc::now().timestamp_millis();
-    let tz_offset_secs = chrono::Local::now().offset().local_minus_utc();
-    context.set_current_time_v1(convert::TryInto::try_into(ms_since_1970).unwrap(), tz_offset_secs.into());
-    */
     match context.eval(line, true, int) {
         Ok(res) => {
             let result: Vec<_> = res.get_main_result_spans().collect();
@@ -76,19 +75,20 @@ fn eval_and_print_res(
 }
 
 fn print_help(explain_quitting: bool) {
-    println!(
-        concat!(
-            "For more information on how to use fend, ",
-            "please take a look at the manual:\n",
-            "https://github.com/printfn/fend/wiki\n\n",
-            "Version: {}{}",
-        ),
-        fend_core::get_version(),
-        config::get_config_file_dir().map_or_else(
-            || "Failed to get config file location".to_string(),
-            |d| format!("\nConfig file: {}", d.to_string_lossy())
-        )
-    );
+    println!("For more information on how to use fend, please take a look at the manual:");
+    println!("https://github.com/printfn/fend/wiki");
+    println!();
+    println!("Version: {}", fend_core::get_version());
+    if let Some(config_path) = file_paths::get_config_file_location() {
+        println!("Config file: {}", config_path.to_string_lossy());
+    } else {
+        println!("Failed to get config file location");
+    }
+    if let Some(history_path) = file_paths::get_history_file_location() {
+        println!("History file: {}", history_path.to_string_lossy());
+    } else {
+        println!("Failed to get history file location");
+    }
     if explain_quitting {
         println!("\nTo quit, type `quit`.");
     }
@@ -108,7 +108,7 @@ fn repl_loop(config: &config::Config) -> i32 {
         rustyline::config::Builder::new()
             .history_ignore_space(true)
             .auto_add_history(true)
-            .max_history_size(10000)
+            .max_history_size(config.max_history_size)
             .build(),
     );
     let core_context = std::cell::RefCell::new(fend_core::Context::new());
@@ -117,8 +117,8 @@ fn repl_loop(config: &config::Config) -> i32 {
     }
     let mut context = Context::new(&core_context);
     rl.set_helper(Some(helper::Helper::new(context.clone(), config)));
-    let history_path = config::get_history_file_path();
-    if let Some(history_path) = history_path.clone() {
+    let history_path = file_paths::get_history_file_location();
+    if let Some(history_path) = &history_path {
         if rl.load_history(history_path.as_path()).is_err() {
             // No previous history
         }
@@ -189,8 +189,12 @@ fn real_main() -> i32 {
             println!("{}", fend_core::get_version());
             0
         }
+        ArgsAction::DefaultConfig => {
+            println!("{}", config::DEFAULT_CONFIG_FILE);
+            0
+        }
         ArgsAction::Eval(expr) => {
-            let config = config::read(false);
+            let config = config::read();
             let core_context = std::cell::RefCell::new(fend_core::Context::new());
             if config.coulomb_and_farad {
                 core_context.borrow_mut().use_coulomb_and_farad();
@@ -206,7 +210,7 @@ fn real_main() -> i32 {
             }
         }
         ArgsAction::Repl => {
-            let config = config::read(true);
+            let config = config::read();
             repl_loop(&config)
         }
     }
@@ -215,7 +219,7 @@ fn real_main() -> i32 {
 impl FromIterator<String> for ArgsAction {
     fn from_iter<T: IntoIterator<Item = String>>(iter: T) -> Self {
         iter.into_iter().fold(ArgsAction::Repl, |action, arg| {
-            use ArgsAction::{Eval, Help, Repl, Version};
+            use ArgsAction::{DefaultConfig, Eval, Help, Repl, Version};
             match (action, arg.as_str()) {
                 // If any argument is shouting for help, print help!
                 (_, "help" | "--help" | "-h") | (Help, _) => Help,
@@ -223,7 +227,11 @@ impl FromIterator<String> for ArgsAction {
                 // Once we're set on printing the version, only a request for help
                 // can overwrite that
                 // NOTE: 'version' is already handled by fend itself
-                (Repl | Eval(_), "--version" | "-v" | "-V") | (Version, _) => Version,
+                (Repl | Eval(_) | DefaultConfig, "--version" | "-v" | "-V") | (Version, _) => {
+                    Version
+                }
+
+                (Repl | Eval(_), "--default-config") | (DefaultConfig, _) => DefaultConfig,
                 // If neither help nor version is requested, evaluate the arguments
                 // Ignore empty arguments, so that `$ fend "" ""` will enter the repl.
                 (Repl, arg) if !arg.trim().is_empty() => Eval(String::from(arg)),
